@@ -2,16 +2,21 @@ from ipaddr import IPv4Address, IPv6Address
 from ipaddr import AddressValueError
 
 
-def is_public_ipv4_address(address):
-    return not is_private_ipv4_address(address)
+def in_private_ip_space(address):
+    ip_address = IPv4Address(address)
+    return any(
+        [ip_address.is_private, ip_address.is_loopback]
+    )
 
+def is_public_ipv4_address(address):
+    try:
+        return not in_private_ip_space(address)
+    except AddressValueError:
+        return False
 
 def is_private_ipv4_address(address):
     try:
-        ip_address = IPv4Address(address)
-        return any(
-            [ip_address.is_private, ip_address.is_loopback]
-        )
+        return in_private_ip_space(address)
     except AddressValueError:
         return False
 
