@@ -70,6 +70,9 @@ class Director(object):
 
     def __init__(self):
         self.activeNetTests = []
+        self.activeDecks = []
+
+        self.activeMeasurements = {}
 
         self.measurementManager = MeasurementManager()
         self.measurementManager.director = self
@@ -290,6 +293,31 @@ class Director(object):
         measurement.result = failure
         return measurement
 
+    def deckStarted(self, deck_id, from_schedule):
+        log.debug("Starting {0} ({1})".format(deck_id,
+                                              'scheduled' if from_schedule
+                                              else 'user-run'))
+        self.activeDecks.append((deck_id, from_schedule))
+
+    def deckFinished(self, deck_id, from_schedule):
+        log.debug("Finished {0} ({1})".format(deck_id,
+                                              'scheduled' if from_schedule
+                                              else 'user-run'))
+        try:
+            self.activeDecks.remove((deck_id, from_schedule))
+        except ValueError:
+            log.error("Completed deck {0} is not actually running".format(
+                deck_id))
+
+    def isDeckRunning(self, deck_id, from_schedule):
+        """
+        :param deck_id: the ID of the deck to check if it's running
+        :param from_schedule:  True if we want to know the status of a
+        scheduled deck run False for user initiated runs.
+        :return: True if the deck is running False otherwise
+        """
+        return (deck_id, from_schedule) in self.activeDecks
+
     def netTestDone(self, net_test):
         self.notify(DirectorEvent("success",
                                   "Successfully ran test {0}".format(
@@ -331,11 +359,15 @@ class Director(object):
         yield net_test.initialize()
         try:
             self.activeNetTests.append(net_test)
+            if measurement_id:
+                self.activeMeasurements[measurement_id] = net_test
             self.measurementManager.schedule(net_test.generateMeasurements())
 
             yield net_test.done
             yield report.close()
         finally:
+            if measurement_id:
+                del self.activeMeasurements[measurement_id]
             self.netTestDone(net_test)
 
     def start_sniffing(self, test_details):
