@@ -28,9 +28,9 @@ class meekTest(httpt.HTTPTest):
 
     """
     name = "Meek fronted requests test"
-    description = "This tests for the Meek Tor pluggable transport "\
-                  "frontend reachability."
-    version = "0.0.1"
+    description = "This test examines whether the domains used by Meek "\
+                  "(a type of Tor bridge) work in your network."
+    version = "0.1.0"
 
     usageOptions = UsageOptions
     inputFile = ['file', 'f', None,
