@@ -3,6 +3,7 @@ from twisted.internet import protocol, defer, reactor
 from ooni.settings import config
 from ooni.nettest import NetTestCase
 from ooni.utils import log
+from ooni.geoip import probe_ip
 
 
 class ProcessDirector(protocol.ProcessProtocol):
@@ -108,9 +109,9 @@ class ProcessTest(NetTestCase):
             self.report['commands'] = []
 
         # Attempt to redact the IP address of the probe from the standard output
-        if config.privacy.includeip is False and config.probe_ip.address is not None:
-            result['stdout'] = result['stdout'].replace(config.probe_ip.address, "[REDACTED]")
-            result['stderr'] = result['stderr'].replace(config.probe_ip.address, "[REDACTED]")
+        if config.privacy.includeip is False and probe_ip.address is not None:
+            result['stdout'] = result['stdout'].replace(probe_ip.address, "[REDACTED]")
+            result['stderr'] = result['stderr'].replace(probe_ip.address, "[REDACTED]")
 
         self.report['commands'].append({
             'command_name': ' '.join(command),
