@@ -1,5 +1,6 @@
 import os
 import shutil
+
 from twisted.trial import unittest
 
 from ooni.settings import config
@@ -9,7 +10,8 @@ class ConfigTestCase(unittest.TestCase):
     def setUp(self):
         self.ooni_home_dir = os.path.abspath("ooni_home")
         self.config = config
-        self.config.initialize_ooni_home("ooni_home")
+        self.config.initialize_ooni_home(self.ooni_home_dir)
+        config.is_initialized = lambda: True
         super(ConfigTestCase, self).setUp()
 
     def skipTest(self, reason):
